pub struct Implementation {
pub name: String,
pub version: String,
pub title: Option<String>,
pub description: Option<String>,
pub website_url: Option<String>,
pub icons: Option<Vec<Icon>>,
}Expand description
Information about an MCP implementation (2025-11-25 with title support)
Fields
name: StringIntended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn’t present).
version: StringVersion of the implementation
title: Option<String>Intended for UI and end-user contexts — improved to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.
description: Option<String>Optional description for UI contexts.
website_url: Option<String>Optional implementation website.
icons: Option<Vec<Icon>>Optional UI icons.
Implementations
Sourceimpl Implementation
impl Implementation
Sourcepub fn new<S: Into<String>>(name: S, version: S) -> Self
pub fn new<S: Into<String>>(name: S, version: S) -> Self
Create a new implementation with name and version
Sourcepub fn with_title<S: Into<String>>(name: S, version: S, title: S) -> Self
pub fn with_title<S: Into<String>>(name: S, version: S, title: S) -> Self
Create implementation with title
Sourcepub fn with_description<S: Into<String>>(self, description: S) -> Self
pub fn with_description<S: Into<String>>(self, description: S) -> Self
Add an optional human-readable description.
Sourcepub fn with_website_url<S: Into<String>>(self, website_url: S) -> Self
pub fn with_website_url<S: Into<String>>(self, website_url: S) -> Self
Add the implementation website URL.
Sourcepub fn with_icons(self, icons: Vec<Icon>) -> Self
pub fn with_icons(self, icons: Vec<Icon>) -> Self
Add UI icons advertised by the implementation.