pub struct ModelHint {
pub name: Option<String>,
pub additional_hints: Option<HashMap<String, Value>>,
}Expand description
Model hint for model selection (2025-11-25)
Fields
name: Option<String>A hint for a model name.
The client SHOULD treat this as a substring of a model name; for example:
claude-3-5-sonnetshould matchclaude-3-5-sonnet-20241022sonnetshould matchclaude-3-5-sonnet-20241022,claude-3-sonnet-20240229, etc.claudeshould match any Claude model
additional_hints: Option<HashMap<String, Value>>Additional provider-specific hints for model selection. Keys not declared here are currently left unspecified by the spec and are up to the client to interpret. This allows provider-specific extensions.