pub struct Resource {
pub uri: String,
pub name: String,
pub description: Option<String>,
pub mime_type: Option<String>,
pub annotations: Option<Annotations>,
pub size: Option<u64>,
pub title: Option<String>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<HashMap<String, Value>>,
}Expand description
Resource definition
Fields
uri: StringURI of the resource
name: StringIntended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn’t present).
description: Option<String>Description of the resource
mime_type: Option<String>MIME type of the resource
annotations: Option<Annotations>Resource annotations (2025-11-25)
size: Option<u64>Resource size in bytes (2025-11-25)
title: Option<String>Intended for UI and end-user contexts
icons: Option<Vec<Icon>>Optional icons for UI rendering.
meta: Option<HashMap<String, Value>>Metadata field for future extensions
Implementations
Sourceimpl Resource
impl Resource
Sourcepub fn from_legacy<S: Into<String>>(uri: S, name: Option<S>) -> Self
pub fn from_legacy<S: Into<String>>(uri: S, name: Option<S>) -> Self
Create a resource from legacy format (name was optional)
Sourcepub fn with_title<S: Into<String>>(self, title: S) -> Self
pub fn with_title<S: Into<String>>(self, title: S) -> Self
Add title to the resource
Sourcepub fn with_description<S: Into<String>>(self, description: S) -> Self
pub fn with_description<S: Into<String>>(self, description: S) -> Self
Add description to the resource
Sourcepub fn with_icons(self, icons: Vec<Icon>) -> Self
pub fn with_icons(self, icons: Vec<Icon>) -> Self
Add icons to the resource metadata.