ServerInfo

Type Alias ServerInfo 

pub type ServerInfo = Implementation;

Aliased Type

pub struct ServerInfo {
    pub name: String,
    pub version: String,
    pub title: Option<String>,
    pub description: Option<String>,
    pub website_url: Option<String>,
    pub icons: Option<Vec<Icon>>,
}

Fields

name: String

Intended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn’t present).

version: String

Version of the implementation

title: Option<String>

Intended for UI and end-user contexts — improved to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.

description: Option<String>

Optional description for UI contexts.

website_url: Option<String>

Optional implementation website.

icons: Option<Vec<Icon>>

Optional UI icons.