pub struct BaseMetadata {
pub name: String,
pub title: Option<String>,
}Expand description
Base interface for metadata with name (identifier) and title (display name) properties.
Fields
name: StringIntended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn’t present).
title: Option<String>Intended for UI and end-user contexts — improved to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.
If not provided, the name should be used for display (except for Tool,
where annotations.title should be given precedence over using name, if present).