pub type ClientInfo = Implementation;Aliased Type
pub struct ClientInfo {
pub name: String,
pub version: String,
pub title: Option<String>,
pub description: Option<String>,
pub website_url: Option<String>,
pub icons: Option<Vec<Icon>>,
}Fields
name: StringIntended for programmatic or logical use, but used as a display name in past specs or fallback (if title isn’t present).
version: StringVersion of the implementation
title: Option<String>Intended for UI and end-user contexts — improved to be human-readable and easily understood, even by those unfamiliar with domain-specific terminology.
description: Option<String>Optional description for UI contexts.
website_url: Option<String>Optional implementation website.
icons: Option<Vec<Icon>>Optional UI icons.